==> zego_plugin_adapter-2.8.0.tar.gz: lib/src/signaling/interface.dart <==
import 'dart:core';
import 'dart:typed_data';

import 'package:flutter/foundation.dart';
import 'package:zego_plugin_adapter/src/defines.dart';
import 'package:zego_plugin_adapter/src/signaling/defines.dart';
import 'package:zego_plugin_adapter/src/signaling/enums.dart';
import 'package:zego_plugin_adapter/src/signaling/errors.dart';
import 'package:zego_zpns/zego_zpns.dart';

part 'part/background_message.dart';

part 'part/callkit.dart';

part 'part/invitation.dart';

part 'part/message.dart';

part 'part/notification.dart';

part 'part/room.dart';

part 'part/user.dart';

/// @nodoc
/// For all apis and events, See mixins.
abstract class ZegoSignalingPluginInterface
    with
        ZegoSignalingPluginRoomAPI,
        ZegoSignalingPluginRoomEvent,
        ZegoSignalingPluginInvitationAPI,
        ZegoSignalingPluginInvitationEvent,
        ZegoSignalingPluginUserAPI,
        ZegoSignalingPluginUserEvent,
        ZegoSignalingPluginNotificationAPI,
        ZegoSignalingPluginNotificationEvent,
        ZegoSignalingPluginMessageAPI,
        ZegoSignalingPluginMessageEvent,
        ZegoSignalingPluginBackgroundMessageAPI,
        ZegoSignalingPluginBackgroundMessageEvent,
        ZegoSignalingPluginCallKitAPI,
        ZegoSignalingPluginCallKitEvent,
        IZegoUIKitPlugin {
  Future<void> init({required int appID, String appSign = ''});

  Future<void> uninit();

  /// get error event stream
  Stream<ZegoSignalingPluginErrorEvent> getErrorEventStream();

  Stream<ZegoSignalingError> getErrorStream();
}

==> zego_plugin_adapter-2.10.1.tar.gz: lib/src/signaling/interface.dart <==
// Dart imports:
import 'dart:core';
import 'dart:typed_data';

// Flutter imports:
import 'package:flutter/foundation.dart';

// Project imports:
import 'package:zego_plugin_adapter/src/defines.dart';
import 'package:zego_plugin_adapter/src/signaling/defines.dart';
import 'package:zego_plugin_adapter/src/signaling/enums.dart';
import 'package:zego_plugin_adapter/src/signaling/errors.dart';

// Package imports:
import 'package:zego_callkit/zego_callkit.dart';

part 'part/background_message.dart';

part 'part/callkit.dart';

part 'part/invitation.dart';

part 'part/message.dart';

part 'part/notification.dart';

part 'part/room.dart';

part 'part/user.dart';

/// @nodoc
/// For all apis and events, See mixins.
abstract class ZegoSignalingPluginInterface
    with
        ZegoSignalingPluginRoomAPI,
        ZegoSignalingPluginRoomEvent,
        ZegoSignalingPluginInvitationAPI,
        ZegoSignalingPluginInvitationEvent,
        ZegoSignalingPluginUserAPI,
        ZegoSignalingPluginUserEvent,
        ZegoSignalingPluginNotificationAPI,
        ZegoSignalingPluginNotificationEvent,
        ZegoSignalingPluginMessageAPI,
        ZegoSignalingPluginMessageEvent,
        ZegoSignalingPluginBackgroundMessageAPI,
        ZegoSignalingPluginBackgroundMessageEvent,
        ZegoSignalingPluginCallKitAPI,
        ZegoSignalingPluginCallKitEvent,
        IZegoUIKitPlugin {
  /// init
  Future<void> init({required int appID, String appSign = ''});

  /// uninit
  Future<void> uninit();

  /// get error event stream from zim
  Stream<ZegoSignalingPluginErrorEvent> getErrorEventStream();

  /// get error stream
  Stream<ZegoSignalingError> getErrorStream();
}
